@@ -24,13 +24,20 @@ class Source:
     name: str
     link: Optional[str]
 
+    def to_json(self):
+        output_dict = {"name": self.name}
+        if self.link is not None:
+            output_dict["link"] = self.link
+        return output_dict
+
 
 def retrieve_update_function_from_mod_obj_and_attr_name(mod_obj: "ModelingObject", attr_name: str):
     update_func_name = f"update_{attr_name}"
     update_func = getattr(mod_obj, update_func_name, None)
 
     if update_func is None:
-        raise AttributeError(f"No update function associated to {attr_name} in {mod_obj.id}, please create it.")
+        raise AttributeError(f"No update function associated to {attr_name} in {mod_obj.class_as_simple_str} "
+                             f"{mod_obj.name} ({mod_obj.id}), please create it.")
 
     return update_func
 
